@@ -41,6 +41,7 @@ void *alloca (size_t);
 #include <stdlib.h>
 #include <string.h>
 #include <stddef.h>
+#include <stdint.h>
 #ifdef HAVE_DIRENT_H
 # include <dirent.h>
 #endif
@@ -68,7 +69,7 @@ void *alloca (size_t);
 #include "eina_log.h"
 #include "eina_xattr.h"
 
-#ifdef HAVE_ESCAPE_H
+#ifdef HAVE_ESCAPE
 # include <Escape.h>
 #endif
 
@@ -500,10 +501,14 @@ slprintf(char *str, size_t size, const char *format, ...)
 static char *
 _eina_file_escape(const char *path, int *length)
 {
-   char *result = strdup(path ? path : "");
-   char *p = result;
-   char *q = result;
-   int len;
+   char *result;
+   char *p;
+   char *q;
+   size_t len;
+
+   result = strdup(path ? path : "");
+   p = result;
+   q = result;
 
    if (!result)
      return NULL;
@@ -983,19 +988,19 @@ eina_file_open(const char *path, Eina_Bool shared)
      {
         file->delete_me = EINA_TRUE;
         eina_hash_del(_eina_file_cache, file->filename, file);
-        _eina_file_real_close(file);
         file = NULL;
      }
 
    if (!file)
      {
-        n = malloc(sizeof (Eina_File) + strlen(filename) + 1);
+        n = malloc(sizeof(Eina_File) + strlen(filename) + 1);
         if (!n)
 	  {
              eina_lock_release(&_eina_file_lock_cache);
              goto on_error;
 	  }
 
+        memset(n, 0, sizeof(Eina_File));
         n->filename = (char*) (n + 1);
         strcpy((char*) n->filename, filename);
         n->map = eina_hash_new(EINA_KEY_LENGTH(_eina_file_map_key_length),
@@ -1005,7 +1010,6 @@ eina_file_open(const char *path, Eina_Bool shared)
                                3);
         n->rmap = eina_hash_pointer_new(NULL);
         n->global_map = MAP_FAILED;
-	n->global_refcount = 0;
         n->length = file_stat.st_size;
         n->mtime = file_stat.st_mtime;
 #ifdef _STAT_VER_LINUX
@@ -1016,10 +1020,8 @@ eina_file_open(const char *path, Eina_Bool shared)
 # endif
 #endif
         n->inode = file_stat.st_ino;
-        n->refcount = 0;
         n->fd = fd;
         n->shared = shared;
-        n->delete_me = EINA_FALSE;
         eina_lock_new(&n->lock);
         eina_hash_direct_add(_eina_file_cache, n->filename, n);
      }
@@ -1047,18 +1049,23 @@ eina_file_open(const char *path, Eina_Bool shared)
 EAPI void
 eina_file_close(Eina_File *file)
 {
+   Eina_Bool leave = EINA_TRUE;
+
    EINA_SAFETY_ON_NULL_RETURN(file);
 
+   eina_lock_take(&_eina_file_lock_cache);
+
    eina_lock_take(&file->lock);
    file->refcount--;
+   if (file->refcount == 0) leave = EINA_FALSE;
    eina_lock_release(&file->lock);
+   if (leave) goto end;
 
-   if (file->refcount != 0) return;
-   eina_lock_take(&_eina_file_lock_cache);
-
-   eina_hash_del(_eina_file_cache, file->filename, file);
+   if (eina_hash_find(_eina_file_cache, file->filename) == file)
+     eina_hash_del(_eina_file_cache, file->filename, file);
    _eina_file_real_close(file);
 
+ end:
    eina_lock_release(&_eina_file_lock_cache);
 }
 
@@ -1127,6 +1134,145 @@ eina_file_map_all(Eina_File *file, Eina_File_Populate rule)
    return ret;
 }
 
+typedef struct _Eina_Lines_Iterator Eina_Lines_Iterator;
+struct _Eina_Lines_Iterator
+{
+   Eina_Iterator iterator;
+
+   Eina_File *fp;
+   const char *map;
+   const char *end;
+
+   int boundary;
+
+   Eina_File_Line current;
+};
+
+/* search '\r' and '\n' by preserving cache locality and page locality
+   in doing a search inside 4K boundary.
+ */
+static inline const char *
+_eina_fine_eol(const char *start, int boundary, const char *end)
+{
+   const char *cr;
+   const char *lf;
+   unsigned long long chunk;
+
+   while (start < end)
+     {
+        chunk = start + boundary < end ? boundary : end - start;
+        cr = memchr(start, '\r', chunk);
+        lf = memchr(start, '\n', chunk);
+        if (cr)
+          {
+             if (lf && lf < cr)
+               return lf + 1;
+             return cr + 1;
+          }
+        else if (lf)
+           return lf + 1;
+
+        start += chunk;
+        boundary = 4096;
+     }
+
+   return end;
+}
+
+static Eina_Bool
+_eina_file_map_lines_iterator_next(Eina_Lines_Iterator *it, void **data)
+{
+   const char *eol;
+   unsigned char match;
+
+   if (it->current.end >= it->end)
+     return EINA_FALSE;
+
+   match = *it->current.end;
+   while ((*it->current.end == '\n' || *it->current.end == '\r')
+          && it->current.end < it->end)
+     {
+        if (match == *it->current.end)
+          it->current.index++;
+        it->current.end++;
+     }
+   it->current.index++;
+
+   if (it->current.end == it->end)
+     return EINA_FALSE;
+
+   eol = _eina_fine_eol(it->current.end,
+                        it->boundary,
+                        it->end);
+   it->boundary = (uintptr_t) eol & 0x3FF;
+   if (it->boundary == 0) it->boundary = 4096;
+
+   it->current.start = it->current.end;
+
+   it->current.end = eol;
+   it->current.length = eol - it->current.start - 1;
+
+   *data = &it->current;
+   return EINA_TRUE;
+}
+
+static Eina_File *
+_eina_file_map_lines_iterator_container(Eina_Lines_Iterator *it)
+{
+   return it->fp;
+}
+
+static void
+_eina_file_map_lines_iterator_free(Eina_Lines_Iterator *it)
+{
+   eina_file_map_free(it->fp, (void*) it->map);
+   eina_file_close(it->fp);
+
+   EINA_MAGIC_SET(&it->iterator, 0);
+   free(it);
+}
+
+EAPI Eina_Iterator *
+eina_file_map_lines(Eina_File *file)
+{
+   Eina_Lines_Iterator *it;
+
+   EINA_SAFETY_ON_NULL_RETURN_VAL(file, NULL);
+
+   if (file->length == 0) return NULL;
+
+   it = calloc(1, sizeof (Eina_Lines_Iterator));
+   if (!it) return NULL;
+
+   EINA_MAGIC_SET(&it->iterator, EINA_MAGIC_ITERATOR);
+
+   it->map = eina_file_map_all(file, EINA_FILE_SEQUENTIAL);
+   if (!it->map)
+     {
+        free(it);
+        return NULL;
+     }
+
+   eina_lock_take(&file->lock);
+   file->refcount++;
+   eina_lock_release(&file->lock);
+
+   it->fp = file;
+   it->boundary = 4096;
+   it->current.start = it->map;
+   it->current.end = it->current.start;
+   it->current.index = 0;
+   it->current.length = 0;
+   it->end = it->map + it->fp->length;
+
+   it->iterator.version = EINA_ITERATOR_VERSION;
+   it->iterator.next = FUNC_ITERATOR_NEXT(_eina_file_map_lines_iterator_next);
+   it->iterator.get_container = FUNC_ITERATOR_GET_CONTAINER(_eina_file_map_lines_iterator_container);
+   it->iterator.free = FUNC_ITERATOR_FREE(_eina_file_map_lines_iterator_free);
+
+   return &it->iterator;
+}
+
 EAPI void *
 eina_file_map_new(Eina_File *file, Eina_File_Populate rule,
                   unsigned long int offset, unsigned long int length)
@@ -1185,7 +1331,7 @@ eina_file_map_new(Eina_File *file, Eina_File_Populate rule,
         if (map->map == MAP_FAILED) goto on_error;
 
         eina_hash_add(file->map, &key, map);
-        eina_hash_direct_add(file->rmap, map->map, map);
+        eina_hash_direct_add(file->rmap, &map->map, map);
      }
 
    map->refcount++;
