@@ -47,6 +47,8 @@
 #include <mcheck.h>
 #endif
 
+#include <time.h>
+
 #include "eina_lock.h"
 #include "eina_config.h"
 #include "eina_private.h"
@@ -101,6 +103,7 @@ static int _eina_log_dom = -1;
 
 EAPI Eina_Bool _eina_threads_activated = EINA_FALSE;
 EAPI Eina_Error EINA_ERROR_NOT_MAIN_LOOP = 0;
+EAPI unsigned int eina_seed = 0;
 
 static const char EINA_ERROR_NOT_MAIN_LOOP_STR[] = "Main loop thread check failed.";
 
@@ -245,6 +248,10 @@ eina_init(void)
    if (EINA_LIKELY(_eina_main_count > 0))
       return ++_eina_main_count;
 
+   srand(time(NULL));
+   while (eina_seed == 0)
+     eina_seed = rand();
+
 #ifdef MT
    if ((getenv("EINA_MTRACE")) && (getenv("MALLOC_TRACE")))
      {
@@ -307,6 +314,11 @@ eina_init(void)
 EAPI int
 eina_shutdown(void)
 {
+   if (_eina_main_count <= 0)
+     {
+        ERR("Init count not greater than 0 in shutdown.");
+        return 0;
+     }
    _eina_main_count--;
    if (EINA_UNLIKELY(_eina_main_count == 0))
      {
@@ -405,8 +417,17 @@ EAPI Eina_Bool
 eina_main_loop_is(void)
 {
 #ifdef EFL_HAVE_THREADS
-   pid_t pid = getpid();
+  pid_t pid;
 
+# ifdef _WIN32
+   if (_eina_main_loop == GetCurrentThreadId())
+     return EINA_TRUE;
+# else
+   if (pthread_equal(_eina_main_loop, pthread_self()))
+     return EINA_TRUE;
+# endif
+
+   pid = getpid();
 # ifdef _WIN32
    if (pid != _eina_pid)
      {
@@ -414,9 +435,7 @@ eina_main_loop_is(void)
         _eina_main_loop = GetCurrentThreadId();
         return EINA_TRUE;
      }
-   if (_eina_main_loop == GetCurrentThreadId())
-     return EINA_TRUE;
-# else
+#else
    if (pid != _eina_pid)
      {
         /* This is in case of a fork, but don't like the solution */
@@ -424,11 +443,9 @@ eina_main_loop_is(void)
         _eina_main_loop = pthread_self();
         return EINA_TRUE;
      }
-
-   if (pthread_equal(_eina_main_loop, pthread_self()))
-     return EINA_TRUE;
-# endif
 #endif
+#endif
+
    return EINA_FALSE;
 }
 
