@@ -65,15 +65,19 @@ _new_va(const char *name,
         const char *options,
         va_list args)
 {
-   Eina_Mempool_Backend *be;
+   Eina_Mempool_Backend *be = NULL;
    Eina_Mempool *mp;
 
    Eina_Error err = EINA_ERROR_NOT_MEMPOOL_MODULE;
 
    eina_error_set(0);
-   be = eina_hash_find(_backends, name);
-   if ((!be) || (!be->init))
-      goto on_error;
+   if (getenv("EINA_MEMPOOL_PASS"))
+     {
+        be = eina_hash_find(_backends, "pass_through");
+        if (!be) be = eina_hash_find(_backends, name);
+     }
+   else be = eina_hash_find(_backends, name);
+   if ((!be) || (!be->init)) goto on_error;
 
    err = EINA_ERROR_OUT_OF_MEMORY;
    mp = calloc(1, sizeof(Eina_Mempool));
