@@ -76,7 +76,7 @@
 #include "eina_hash.h"
 #include "eina_rbtree.h"
 #include "eina_error.h"
-#include "eina_log.h"
+#include "eina_lock.h"
 
 /* undefs EINA_ARG_NONULL() so NULL checks are not compiled out! */
 #include "eina_safety_checks.h"
@@ -96,6 +96,7 @@
 static const char EINA_MAGIC_SHARE_STR[] = "Eina Share";
 static const char EINA_MAGIC_SHARE_HEAD_STR[] = "Eina Share Head";
 
+static int _eina_share_common_count = 0;
 
 #define EINA_MAGIC_CHECK_SHARE_COMMON_HEAD(d, unlock, ...)      \
    do {                                                          \
@@ -124,8 +125,6 @@ typedef struct _Eina_Share_Common Eina_Share_Common;
 typedef struct _Eina_Share_Common_Node Eina_Share_Common_Node;
 typedef struct _Eina_Share_Common_Head Eina_Share_Common_Head;
 
-int _eina_share_common_log_dom = -1;
-
 struct _Eina_Share
 {
    Eina_Share_Common *share;
@@ -169,27 +168,9 @@ struct _Eina_Share_Common_Head
    Eina_Share_Common_Node builtin_node;
 };
 
-#ifdef EFL_HAVE_THREADS
 Eina_Bool _share_common_threads_activated = EINA_FALSE;
 
-# ifdef EFL_HAVE_POSIX_THREADS
-static pthread_mutex_t _mutex_big = PTHREAD_MUTEX_INITIALIZER;
-#  define SHARE_COMMON_LOCK_BIG() if(_share_common_threads_activated) \
-      pthread_mutex_lock(&_mutex_big)
-#  define SHARE_COMMON_UNLOCK_BIG() if(_share_common_threads_activated) \
-      pthread_mutex_unlock(&_mutex_big)
-# else /* EFL_HAVE_WIN32_THREADS */
-static HANDLE _mutex_big = NULL;
-#  define SHARE_COMMON_LOCK_BIG() if(_share_common_threads_activated) \
-      WaitForSingleObject(_mutex_big, INFINITE)
-#  define SHARE_COMMON_UNLOCK_BIG() if(_share_common_threads_activated) \
-      ReleaseMutex(_mutex_big)
-
-# endif /* EFL_HAVE_WIN32_THREADS */
-#else /* EFL_HAVE_THREADS */
-# define SHARE_COMMON_LOCK_BIG() do {} while (0)
-# define SHARE_COMMON_UNLOCK_BIG() do {} while (0)
-#endif
+static Eina_Lock _mutex_big;
 
 #ifdef EINA_SHARE_COMMON_USAGE
 struct _Eina_Share_Common_Population
@@ -269,7 +250,7 @@ _eina_share_common_population_stats(Eina_Share *share)
 void
 eina_share_common_population_add(Eina_Share *share, int slen)
 {
-   SHARE_COMMON_LOCK_BIG();
+   eina_lock_take(&_mutex_big);
 
    share->population.count++;
    if (share->population.count > share->population.max)
@@ -284,19 +265,19 @@ eina_share_common_population_add(Eina_Share *share, int slen)
               share->population_group[slen].count;
      }
 
-   SHARE_COMMON_UNLOCK_BIG();
+   eina_lock_release(&_mutex_big);
 }
 
 void
 eina_share_common_population_del(Eina_Share *share, int slen)
 {
-   SHARE_COMMON_LOCK_BIG();
+   eina_lock_take(&_mutex_big);
 
    share->population.count--;
    if (slen < 4)
       share->population_group[slen].count--;
 
-   SHARE_COMMON_UNLOCK_BIG();
+   eina_lock_release(&_mutex_big);
 }
 
 static void
@@ -571,8 +552,6 @@ eina_iterator_array_check(const Eina_Rbtree *rbtree __UNUSED__,
 {
    Eina_Share_Common_Node *node;
 
-   SHARE_COMMON_LOCK_BIG();
-
    fdata->used += sizeof(Eina_Share_Common_Head);
    for (node = head->head; node; node = node->next)
      {
@@ -585,8 +564,6 @@ eina_iterator_array_check(const Eina_Rbtree *rbtree __UNUSED__,
         fdata->unique++;
      }
 
-   SHARE_COMMON_UNLOCK_BIG();
-
    return EINA_TRUE;
 }
 
@@ -616,32 +593,12 @@ eina_share_common_init(Eina_Share **_share,
                        const char *node_magic_STR)
 {
    Eina_Share *share;
+
    share = *_share = calloc(sizeof(Eina_Share), 1);
-   if (!share)
-      return EINA_FALSE;
-
-   if (_eina_share_common_log_dom < 0) /*Only register if not already */
-      _eina_share_common_log_dom = eina_log_domain_register(
-            "eina_share",
-            EINA_LOG_COLOR_DEFAULT);
-
-   if (_eina_share_common_log_dom < 0)
-     {
-        EINA_LOG_ERR("Could not register log domain: eina_share_common");
-        return EINA_FALSE;
-     }
+   if (!share) goto on_error;
 
    share->share = calloc(1, sizeof(Eina_Share_Common));
-   if (!share->share)
-     {
-        if (_eina_share_common_log_dom > 0)
-          {
-             eina_log_domain_unregister(_eina_share_common_log_dom);
-             _eina_share_common_log_dom = -1;
-          }
-
-        return EINA_FALSE;
-     }
+   if (!share->share) goto on_error;
 
    share->node_magic = node_magic;
 #define EMS(n) eina_magic_string_static_set(n, n ## _STR)
@@ -652,7 +609,17 @@ eina_share_common_init(Eina_Share **_share,
    EINA_MAGIC_SET(share->share, EINA_MAGIC_SHARE);
 
    _eina_share_common_population_init(share);
+
+   /* below is the common part among other all eina_share_common user */
+   if (_eina_share_common_count++ != 0)
+     return EINA_TRUE;
+
+   eina_lock_new(&_mutex_big);
    return EINA_TRUE;
+
+ on_error:
+   _eina_share_common_count--;
+   return EINA_FALSE;
 }
 
 /**
@@ -672,7 +639,7 @@ eina_share_common_shutdown(Eina_Share **_share)
    unsigned int i;
    Eina_Share *share = *_share;
 
-   SHARE_COMMON_LOCK_BIG();
+   eina_lock_take(&_mutex_big);
 
    _eina_share_common_population_stats(share);
 
@@ -688,16 +655,18 @@ eina_share_common_shutdown(Eina_Share **_share)
    MAGIC_FREE(share->share);
 
    _eina_share_common_population_shutdown(share);
-   if (_eina_share_common_log_dom > 0) /* Only free if necessary */
-     {
-        eina_log_domain_unregister(_eina_share_common_log_dom);
-        _eina_share_common_log_dom = -1;
-     }
 
-   SHARE_COMMON_UNLOCK_BIG();
+   eina_lock_release(&_mutex_big);
 
    free(*_share);
    *_share = NULL;
+
+   /* below is the common part among other all eina_share_common user */
+   if (--_eina_share_common_count != 0)
+     return EINA_TRUE;
+
+   eina_lock_free(&_mutex_big);
+
    return EINA_TRUE;
 }
 
@@ -765,7 +734,7 @@ eina_share_common_add_length(Eina_Share *share,
    hash_num = hash & 0xFF;
    hash = (hash >> 8) & EINA_SHARE_COMMON_MASK;
 
-   SHARE_COMMON_LOCK_BIG();
+   eina_lock_take(&_mutex_big);
    p_bucket = share->share->buckets + hash_num;
 
    ed = _eina_share_common_find_hash(*p_bucket, hash);
@@ -777,27 +746,27 @@ eina_share_common_add_length(Eina_Share *share,
                                                     str,
                                                     slen,
                                                     null_size);
-        SHARE_COMMON_UNLOCK_BIG();
+        eina_lock_release(&_mutex_big);
         return s;
      }
 
-   EINA_MAGIC_CHECK_SHARE_COMMON_HEAD(ed, SHARE_COMMON_UNLOCK_BIG(), NULL);
+   EINA_MAGIC_CHECK_SHARE_COMMON_HEAD(ed, eina_lock_release(&_mutex_big), NULL);
 
    el = _eina_share_common_head_find(ed, str, slen);
    if (el)
      {
         EINA_MAGIC_CHECK_SHARE_COMMON_NODE(el,
                                            share->node_magic,
-                                           SHARE_COMMON_UNLOCK_BIG());
+                                           eina_lock_release(&_mutex_big));
         el->references++;
-                                           SHARE_COMMON_UNLOCK_BIG();
+                                           eina_lock_release(&_mutex_big);
         return el->str;
      }
 
    el = _eina_share_common_node_alloc(slen, null_size);
    if (!el)
      {
-                                           SHARE_COMMON_UNLOCK_BIG();
+                                           eina_lock_release(&_mutex_big);
         return NULL;
      }
 
@@ -806,7 +775,7 @@ eina_share_common_add_length(Eina_Share *share,
    ed->head = el;
    _eina_share_common_population_head_add(share, ed);
 
-   SHARE_COMMON_UNLOCK_BIG();
+   eina_lock_release(&_mutex_big);
 
    return el->str;
 }
@@ -819,13 +788,16 @@ eina_share_common_ref(Eina_Share *share, const char *str)
    if (!str)
       return NULL;
 
-   SHARE_COMMON_LOCK_BIG();
+   eina_lock_take(&_mutex_big);
    node = _eina_share_common_node_from_str(str, share->node_magic);
-   if (!node) return str;
+   if (!node)
+     {
+        eina_lock_release(&_mutex_big);
+        return str;
+     }
    node->references++;
-   DBG("str=%p refs=%u", str, node->references);
 
-   SHARE_COMMON_UNLOCK_BIG();
+   eina_lock_release(&_mutex_big);
 
    eina_share_common_population_add(share, node->length);
 
@@ -833,7 +805,7 @@ eina_share_common_ref(Eina_Share *share, const char *str)
 }
 
 
-void
+Eina_Bool
 eina_share_common_del(Eina_Share *share, const char *str)
 {
    unsigned int slen;
@@ -843,25 +815,23 @@ eina_share_common_del(Eina_Share *share, const char *str)
    int hash_num, hash;
 
    if (!str)
-      return;
+      return EINA_TRUE;
 
-   SHARE_COMMON_LOCK_BIG();
+   eina_lock_take(&_mutex_big);
 
    node = _eina_share_common_node_from_str(str, share->node_magic);
    if (!node)
-      return;
+      goto on_error;
 
    slen = node->length;
    eina_share_common_population_del(share, slen);
    if (node->references > 1)
      {
         node->references--;
-        DBG("str=%p refs=%u", str, node->references);
-        SHARE_COMMON_UNLOCK_BIG();
-        return;
+        eina_lock_release(&_mutex_big);
+        return EINA_TRUE;
      }
 
-   DBG("str=%p refs=0, delete.", str);
    node->references = 0;
 
    hash = eina_hash_superfast(str, slen);
@@ -873,7 +843,7 @@ eina_share_common_del(Eina_Share *share, const char *str)
    if (!ed)
       goto on_error;
 
-   EINA_MAGIC_CHECK_SHARE_COMMON_HEAD(ed, SHARE_COMMON_UNLOCK_BIG());
+   EINA_MAGIC_CHECK_SHARE_COMMON_HEAD(ed, eina_lock_release(&_mutex_big), EINA_FALSE);
 
    if (!_eina_share_common_head_remove_node(ed, node))
       goto on_error;
@@ -886,14 +856,14 @@ eina_share_common_del(Eina_Share *share, const char *str)
    else
       _eina_share_common_population_head_del(share, ed);
 
-   SHARE_COMMON_UNLOCK_BIG();
+   eina_lock_release(&_mutex_big);
 
-   return;
+   return EINA_TRUE;
 
 on_error:
-   SHARE_COMMON_UNLOCK_BIG();
+   eina_lock_release(&_mutex_big);
    /* possible segfault happened before here, but... */
-   CRITICAL("EEEK trying to del non-shared share_common \"%s\"", str);
+   return EINA_FALSE;
 }
 
 int
@@ -927,7 +897,7 @@ eina_share_common_dump(Eina_Share *share, void (*additional_dump)(
    printf("DDD:   len   ref string\n");
    printf("DDD:-------------------\n");
 
-   SHARE_COMMON_LOCK_BIG();
+   eina_lock_take(&_mutex_big);
    for (i = 0; i < EINA_SHARE_COMMON_BUCKETS; i++)
      {
         if (!share->share->buckets[i])
@@ -971,7 +941,7 @@ eina_share_common_dump(Eina_Share *share, void (*additional_dump)(
               share->population_group[i].max);
 #endif
 
-   SHARE_COMMON_UNLOCK_BIG();
+   eina_lock_release(&_mutex_big);
 }
 
 /**
